@@ -77,7 +77,6 @@ class CustomTitlebarWindow(FramelessWindow):
         if obj == self:
             # catch resize event or window state change event
             if e.type() == 14 or e.type() == 105:
-                self.__toggleNormalOrMaximized()
                 # prevent the problem that top title bar window is not visible when full screen turning off
                 if e.type() == 105:
                     if int(e.oldState()) == 4:
@@ -140,18 +139,8 @@ class CustomTitlebarWindow(FramelessWindow):
             self._move()
 
     def __showNormalOrMaximized(self):
-        self.__toggleNormalOrMaximized()
         self.__execShowNormalOrMaximized()
 
-    def __toggleNormalOrMaximized(self):
-        if self.__style == 'windows':
-            if self.isMaximized():
-                self.__maximizeBtn.setText('🗗')
-            else:
-                self.__maximizeBtn.setText('🗖')
-        elif self.__style == 'mac':
-            pass
-
     def __execShowNormalOrMaximized(self):
         if self.isMaximized():
             self.showNormal()
@@ -161,17 +150,21 @@ class CustomTitlebarWindow(FramelessWindow):
     def setButtonHint(self, hint):
         self.__btnHint = hint
 
+    def __getProperButtonsWidget(self, widget, btnWidget=None):
+        if btnWidget:
+            pass
+        else:
+            if self.__style == 'windows':
+                btnWidget = WindowsButtonsWidget(widget, self.__btnHint)
+            elif self.__style == 'mac':
+                btnWidget = MacButtonsWidget(widget, self.__btnHint)
+        return btnWidget
+
     # btnWidget(user-customized button widget), currently being developed
     def setButtons(self, btnWidget=None, align=Qt.AlignRight):
         # If window has a TopTitleBarWidget
         if isinstance(self.__topTitleBar, TopTitleBarWidget):
-            if btnWidget:
-                self.__btnWidget = btnWidget
-            else:
-                if self.__style == 'windows':
-                    self.__btnWidget = WindowsButtonsWidget(self.__topTitleBar, self.__btnHint)
-                elif self.__style == 'mac':
-                    self.__btnWidget = MacButtonsWidget(self.__topTitleBar, self.__btnHint)
+            self.__btnWidget = self.__getProperButtonsWidget(self.__topTitleBar, btnWidget)
             self.__topTitleBar.setButtons(self.__btnWidget, align)
             iconTitleWidget = self.__topTitleBar.getIconTitleWidget()
             self.initTitleEvent(iconTitleWidget)
@@ -180,14 +173,7 @@ class CustomTitlebarWindow(FramelessWindow):
         else:
             lay = QHBoxLayout()
             lay.setContentsMargins(0, 0, 0, 0)
-
-            if btnWidget:
-                self.__btnWidget = btnWidget
-            else:
-                if self.__style == 'windows':
-                    self.__btnWidget = WindowsButtonsWidget(self.__menubar, self.__btnHint)
-                elif self.__style == 'mac':
-                    self.__btnWidget = MacButtonsWidget(self.__menubar, self.__btnHint)
+            self.__btnWidget = self.__getProperButtonsWidget(self.__menubar, btnWidget)
             self.initButtonsEvent()
             lay.addWidget(self.__btnWidget)
 
